@@ -1,7 +1,7 @@
 use strict;
 use warnings;
 package Software::License::AGPL_3;
-$Software::License::AGPL_3::VERSION = '0.103012';
+$Software::License::AGPL_3::VERSION = '0.104001';
 use parent 'Software::License';
 # ABSTRACT: GNU Affero General Public License, Version 3
 
@@ -10,6 +10,7 @@ sub url  { 'http://www.gnu.org/licenses/agpl-3.0.txt' }
 
 sub meta_name  { 'open_source' }
 sub meta2_name { 'agpl_3' }
+sub spdx_expression { 'AGPL-3.0' }
 
 1;
 
@@ -23,15 +24,15 @@ Software::License::AGPL_3 - GNU Affero General Public License, Version 3
 
 =head1 VERSION
 
-version 0.103012
+version 0.104001
 
 =head1 AUTHOR
 
-Ricardo Signes <rjbs@cpan.org>
+Ricardo Signes <rjbs@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Ricardo Signes.
+This software is copyright (c) 2021 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
