@@ -1,7 +1,7 @@
 use strict;
 use warnings;
 package Software::License::Apache_2_0;
-$Software::License::Apache_2_0::VERSION = '0.103014';
+$Software::License::Apache_2_0::VERSION = '0.104001';
 use parent 'Software::License';
 # ABSTRACT: The Apache License, Version 2.0
 
@@ -11,6 +11,20 @@ sub meta_name  { 'apache' }
 sub meta2_name { 'apache_2_0' }
 sub spdx_expression { 'Apache-2.0' }
 
+sub fulltext {
+    my ($self) = @_;
+
+    my $txt = $self->SUPER::fulltext();
+
+    my $year = $self->year;
+    my $holder = $self->holder;
+
+    $txt =~ s{\Q[yyyy]\E}{$year}g;
+    $txt =~ s{\Q[name of copyright owner]\E}{$holder}g;
+
+    return $txt;
+}
+
 1;
 
 =pod
@@ -23,15 +37,15 @@ Software::License::Apache_2_0 - The Apache License, Version 2.0
 
 =head1 VERSION
 
-version 0.103014
+version 0.104001
 
 =head1 AUTHOR
 
-Ricardo Signes <rjbs@cpan.org>
+Ricardo Signes <rjbs@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018 by Ricardo Signes.
+This software is copyright (c) 2021 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
