@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package Software::License::Custom;
 # ABSTRACT: custom license handler
-$Software::License::Custom::VERSION = '0.103014';
+$Software::License::Custom::VERSION = '0.104001';
 use parent 'Software::License';
 
 use Carp;
@@ -213,7 +213,7 @@ Software::License::Custom - custom license handler
 
 =head1 VERSION
 
-version 0.103014
+version 0.104001
 
 =head1 DESCRIPTION
 
@@ -348,11 +348,11 @@ version
 
 =head1 AUTHOR
 
-Ricardo Signes <rjbs@cpan.org>
+Ricardo Signes <rjbs@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018 by Ricardo Signes.
+This software is copyright (c) 2021 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
