@@ -1,7 +1,7 @@
 use strict;
 use warnings;
 package Software::License::FreeBSD;
-$Software::License::FreeBSD::VERSION = '0.103011';
+$Software::License::FreeBSD::VERSION = '0.104001';
 use parent 'Software::License';
 # ABSTRACT: The FreeBSD License (aka two-clause BSD)
 
@@ -10,6 +10,7 @@ sub url  { 'http://www.freebsd.org/copyright/freebsd-license.html' }
 
 sub meta_name  { 'open_source' }
 sub meta2_name { 'freebsd' }
+sub spdx_expression  { 'BSD-2-Clause-FreeBSD' }
 
 1;
 
@@ -23,15 +24,15 @@ Software::License::FreeBSD - The FreeBSD License (aka two-clause BSD)
 
 =head1 VERSION
 
-version 0.103011
+version 0.104001
 
 =head1 AUTHOR
 
-Ricardo Signes <rjbs@cpan.org>
+Ricardo Signes <rjbs@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Ricardo Signes.
+This software is copyright (c) 2021 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
